Arguments
folderOutput
An existing folder (this is tested and can eventually
raise an error) in which the generated results will be written and the
precomputed results will be inflated.
testFileBAM_folderName
The folder in which the BAM file for results
generation stands (.testFunctional passes the path to the
package-embedded test BAM file)
testFileBAM_fileName
The filename of the BAM file used to generate the
results (.testFunctional passes the name of the package-embedded test
BAM file)
testFileMulti_fileName
The filename of the file that is used as test
to generate ouptut results for comparison. It simulates reads that were
treated with the multiread processing functions before injecting it in the
pipeline.
testType
A value in c("regular", "complete"). A regular test will
generate ~15 WIG and GFF files, a complete test however generates ~750 result
files from the test BAM file and aims at passing in all possible loops and
blocks of the pipeline.
verbose
Logical. If verbose is FALSE, the pipeline stdout will be
redirected to a log file to avoid overflow of test messages.